@@ -27,16 +27,19 @@ SUPPORTED_ARCHS = [
     "SKX",
     "CSX",
     "ICL",
+    "ICX",
     "ZEN1",
     "ZEN2",
+    "ZEN3",
     "TX2",
     "N1",
     "A64FX",
+    "TSV110",
     "A72",
 ]
 DEFAULT_ARCHS = {
     "aarch64": "A64FX",
-    "x86": "SKX",
+    "x86": "ICX",
 }
 
 
@@ -95,8 +98,8 @@ def create_parser(parser=None):
     parser.add_argument(
         "--arch",
         type=str,
-        help="Define architecture (SNB, IVB, HSW, BDW, SKX, CSX, ICL, ZEN1, ZEN2, TX2, N1, "
-        "A64FX, A72). If no architecture is given, OSACA assumes a default uarch for x86/AArch64.",
+        help="Define architecture (SNB, IVB, HSW, BDW, SKX, CSX, ICL, ICX, ZEN1, ZEN2, ZEN3, TX2, N1, "
+        "A64FX, TSV110, A72). If no architecture is given, OSACA assumes a default uarch for x86/AArch64.",
     )
     parser.add_argument(
         "--fixed",
@@ -327,6 +330,7 @@ def inspect(args, output_file=sys.stdout):
     # Do optimal schedule for kernel throughput if wished
     if not args.fixed:
         semantics.assign_optimal_throughput(kernel)
+        semantics.assign_optimal_throughput(kernel)
 
     # Create DiGrahps
     kernel_graph = KernelDG(kernel, parser, machine_model, semantics, args.lcd_timeout)
