@@ -29,7 +29,9 @@ class ParserAArch64(BaseParser):
         decimal_number = pp.Combine(
             pp.Optional(pp.Literal("-")) + pp.Word(pp.nums)
         ).setResultsName("value")
-        hex_number = pp.Combine(pp.Literal("0x") + pp.Word(pp.hexnums)).setResultsName("value")
+        hex_number = pp.Combine(
+            pp.Optional(pp.Literal("-")) + pp.Literal("0x") + pp.Word(pp.hexnums)
+        ).setResultsName("value")
         relocation = pp.Combine(pp.Literal(":") + pp.Word(pp.alphanums + "_") + pp.Literal(":"))
         first = pp.Word(pp.alphas + "_.", exact=1)
         rest = pp.Word(pp.alphanums + "_.")
@@ -102,6 +104,7 @@ class ParserAArch64(BaseParser):
             ^ pp.CaselessLiteral("ror")
             ^ pp.CaselessLiteral("sxtw")
             ^ pp.CaselessLiteral("uxtw")
+            ^ pp.CaselessLiteral("uxtb")
             ^ pp.CaselessLiteral("mul vl")
         )
         arith_immediate = pp.Group(
@@ -382,7 +385,7 @@ class ParserAArch64(BaseParser):
             base["prefix"] = "x"
         if index is not None and "name" in index and index["name"] == "sp":
             index["prefix"] = "x"
-        valid_shift_ops = ["lsl", "uxtw", "sxtw"]
+        valid_shift_ops = ["lsl", "uxtw", "uxtb", "sxtw"]
         if "index" in memory_address:
             if "shift" in memory_address["index"]:
                 if memory_address["index"]["shift_op"].lower() in valid_shift_ops:
@@ -537,7 +540,7 @@ class ParserAArch64(BaseParser):
         exponent = int(ieee_val["exponent"], 10)
         if ieee_val["e_sign"] == "-":
             exponent *= -1
-        return float(ieee_val["mantissa"]) * (10 ** exponent)
+        return float(ieee_val["mantissa"]) * (10**exponent)
 
     def parse_register(self, register_string):
         raise NotImplementedError
